# Python Scripts

Guild support running of Python scripts directly via the
`python_script` plugin.

We use the `python-script` sample project for these tests.

    >>> cd(sample("projects", "python-script"))

## Op data for Python scripts

The Python plugin examines Python scripts to infer operation
settings. We use the `op_data_for_script` to illustrate.

    >>> from guild.plugins.python_script import op_data_for_script

Helper function to print op data for a script along with any warnings
generated by the plugin:

    >>> def op_data(script):
    ...     with LogCapture() as log:
    ...         data = op_data_for_script(script)
    ...     if log:
    ...         log.print_all()
    ...     pprint(data)

Empty Python script:

    >>> op_data("empty.py")
    {'exec': '${python_exe} -um guild.op_main empty ${flag_args}',
     'flags': {},
     'flags-dest': 'globals',
     'objective': None,
     'output-scalars': None,
     'plugins': [],
     'sourcecode': None}

Simple script:

    >>> op_data("simple.py")
    {'exec': '${python_exe} -um guild.op_main simple ${flag_args}',
     'flags': {'layers': {'arg-split': None, 'default': 32, 'type': 'number'},
               'name': {'arg-split': None, 'default': 'foo', 'type': 'string'},
               'noise': {'arg-split': None, 'default': 3, 'type': 'number'},
               'skip_connections': {'arg-split': None,
                                    'default': True,
                                    'type': 'boolean'}},
     'flags-dest': 'globals',
     'objective': None,
     'output-scalars': None,
     'plugins': [],
     'sourcecode': None}

## Run Python scripts as Guild operations

Use a new Guild home to isolate runs.

    >>> set_guild_home(mkdtemp())

Simple script:

    >>> run("guild run simple.py -y")
    <exit 0>

    >>> run("guild runs info")
    id: ...
    operation: simple.py
    from: .../samples/projects/python-script
    status: completed
    started: ...
    stopped: ...
    marked: no
    label: layers=32 name=foo noise=3 skip_connections=yes
    sourcecode_digest: ...
    vcs_commit:...
    run_dir: ...
    command: ... -um guild.op_main simple --layers 32
             --name foo --noise 3 --skip_connections true
    exit_status: 0
    pid:
    tags:
    flags:
      layers: 32
      name: foo
      noise: 3
      skip_connections: yes
    scalars:
    <exit 0>
