---
doctest: +FIXME
---

# R script support

Guild provides support for R script via the `r_script` plugin.

We'll use the `r-script` sample project in these tests.

    >>> cd(sample("projects", "r-script"))

## Op data for R script

The R plugin examines R scripts to infer operation settings. We use
the `op_data_for_script` to illustrate.

    >>> from guild.plugins.r_script import op_data_for_script

Helper function to print op data for a script along with any warnings
generated by the plugin:

    >>> def op_data(script):
    ...     with LogCapture() as log:
    ...         data = op_data_for_script(script)
    ...     if log:
    ...         log.print_all()
    ...     pprint(data)

Empty R script:

    >>> op_data("empty.R")
    WARNING: Error in if (is_anno[1]) { : missing value where TRUE/FALSE needed
    Calls: <Anonymous> -> print.yaml -> <Anonymous> -> r_script_guild_data
    Execution halted
    {}

Simple script:

    >>> op_data("simple.R")
    {'exec': '...Rscript -e guildai:::\'do_guild_run("simple.R", '
             'flags_dest = "globals", echo = TRUE)\' ${flag_args}',
     'flags': {'layers': {'default': 32, 'type': 'int'},
               'name': {'default': 'foo', 'type': 'string'},
               'noise': {'default': 3.0, 'type': 'float'},
               'skip_connections': {'default': True, 'type': 'bool'}},
     'flags-dest': 'globals',
     'name': 'simple.R',
     'sourcecode': {'dest': '.'}}

## Run R scripts as Guild operations

    >>> run("guild run simple.R -y")
    WARNING: unknown flag type 'bool' for skip_connections - cannot coerce
    WARNING: unknown option '--layers'
    <BLANKLINE>
    > noise = 3
    > layers <- 32L
    > layers = 4
    > name = "foo"
    > skip_connections = TRUE
    <exit 0>

## Notes

- Support empty file (edge case but we want this for test narrative)

- Flag type 'bool' -> 'boolean'

- If the Guild 'data' decoding is in a separate package, we might want
  to move that logic to the Python side even if it's implemented in R
  (interface via system process). This logic is central to what
  plugins provide and the dependency on another
  repo/build/deploy/install process and the versioning issues is
  probably something we want to avoid. If there is code shared across
  the two repos that could foil this thinking but we should look at
  some other options if we can thinking of any.

- The 'sourcecode' attr in simple.R look good - I wonder if the
  upstream warnings are somehow foiling Guild's correct copying of
  source code. They shouldn't - and that'd probably be a bug in
  Guild. But the config looks correct.
